using System;
using System.Web.UI;
using System.Web.UI.WebControls;
using Microsoft.SharePoint;
using Microsoft.SharePoint.WebPartPages;

namespace RH
{
	/// <summary>
	/// Description of the toolpart. Override the GetToolParts method in your Web Part
	/// class to invoke this toolpart. To establish a reference to the Web Part 
	/// the user has selected, use the ParentToolPane.SelectedWebPart property.
	/// </summary>
	public class PwdToolPart: Microsoft.SharePoint.WebPartPages.ToolPart
	{
        private string FormWebUrl;
        private string FormWebUrlParameter;
        private string FormWebUser;
        private string FormWebPassword;
		private string WebErrorMessage;
        private string FormProxyUrl;
        private string FormProxyUser;
        private string FormProxyPassword;
        private string ProxyErrorMessage;

		/// <summary>
		/// Constructor for the class. A great place to set Set default values for
		/// additional base class properties here.
		/// <summary>
		public PwdToolPart()
		{
			//Set defaults
			this.UseDefaultStyles = true;
			this.AllowMinimize = true;
			this.Title = "Website Authentification";
			this.Init += new EventHandler(CustomToolPart_Init);
		}

		private void CustomToolPart_Init(object sender, System.EventArgs e)
		{
			ToolPane tp = this.ParentToolPane;
			RH.ShowWebsite ShowWebsite = (ShowWebsite)tp.SelectedWebPart;

            FormWebUrl = this.UniqueID + "WebUrl";
            FormWebUrlParameter = this.UniqueID + "WebUrlParameter";
            FormWebUser = this.UniqueID + "WebName";
            FormWebPassword = this.UniqueID + "WebPwd";
			WebErrorMessage = "";

            FormProxyUrl = this.UniqueID + "ProxyUrl";
            FormProxyUser = this.UniqueID + "ProxyName";
            FormProxyPassword = this.UniqueID + "ProxyPwd";
            ProxyErrorMessage = "";
		}
       
		///	<summary>
		///	Called by the tool pane to apply property changes to the selected Web Part. 
		///	</summary>
		public override void ApplyChanges()
		{
			// apply property values here
			ToolPane tp = this.ParentToolPane;
            RH.ShowWebsite ShowWebsite = (ShowWebsite)tp.SelectedWebPart;

            string _WebUrl = Page.Request.Form[FormWebUrl].Trim();
            string _WebUrlParameter = Page.Request.Form[FormWebUrlParameter].Trim();
            string _WebName = Page.Request.Form[FormWebUser].Trim();
            string _WebPwd = Page.Request.Form[FormWebPassword].Trim();
            WebErrorMessage = "";
            string _ProxyUrl = Page.Request.Form[FormProxyUrl].Trim();
            string _ProxyName = Page.Request.Form[FormProxyUser].Trim();
            string _ProxyPwd = Page.Request.Form[FormProxyPassword].Trim();
			ProxyErrorMessage = "";

			if (_WebUrl.Length == 0)
                WebErrorMessage += "<br><strong>Please configure a Website Url.</strong>";
            if (_WebUrl.IndexOf("{") != -1 && _WebUrlParameter.Length == 0)
                WebErrorMessage += "<br><strong>Please specify a Url Parameter.</strong>";
            if (_WebName.Length == 0)
                WebErrorMessage += "<br><strong>Please specify a User.</strong>";
            if (_WebPwd.Length == 0)
                WebErrorMessage += "<br><strong>Please specify a Password.</strong>";
            if (WebErrorMessage.Length > 0)
                WebErrorMessage += "<br>";
            if (_ProxyUrl.Length == 0)
                ProxyErrorMessage += "<br><strong>No Proxy configured</strong>";

            ShowWebsite.WebUrl = _WebUrl;
            ShowWebsite.WebUrlParameter = _WebUrlParameter;
            ShowWebsite.WebUser = _WebName;
			//if (_WebPwd != "*****" && _WebPwd != "") // Nur ndern falls es ein neues valides PWD ist
				ShowWebsite.WebPassword = _WebPwd;
            ShowWebsite.ProxyUrl = _ProxyUrl;
            ShowWebsite.ProxyUser = _ProxyName;
            //if (_ProxyPwd != "*****" && _ProxyPwd != "") // Nur ndern falls es ein neues valides PWD ist
                ShowWebsite.ProxyPassword = _ProxyPwd;
		}

		//		/// <summary>
		//		///	If the ApplyChanges method succeeds, this method is called by the tool pane 
		//		///	to refresh the specified property values in the toolpart user interface.
		//		/// </summary>
		public override void SyncChanges()
		{
			ToolPane tp = this.ParentToolPane;
            RH.ShowWebsite ShowWebsite = (ShowWebsite)tp.SelectedWebPart;

            Page.Request.Form[FormWebUrl] = ShowWebsite.WebUrl;
            Page.Request.Form[FormWebUrlParameter] = ShowWebsite.WebUrlParameter;
            Page.Request.Form[FormWebUser] = ShowWebsite.WebUser;
            Page.Request.Form[FormWebPassword] = ShowWebsite.WebPassword;
            Page.Request.Form[FormProxyUrl] = ShowWebsite.ProxyUrl;
            Page.Request.Form[FormProxyUser] = ShowWebsite.ProxyUser;
            Page.Request.Form[FormProxyPassword] = ShowWebsite.ProxyPassword;
        }
		

		/// <summary>
		/// Render this Tool part to the output parameter specified.
		/// </summary>
		/// <param name="output"> The HTML writer to write out to </param>
		protected override void RenderToolPart(HtmlTextWriter output)
		{
			ToolPane tp = this.ParentToolPane;
            RH.ShowWebsite myWP = (RH.ShowWebsite)tp.SelectedWebPart;

            output.Write("<span>Website</span><br><input name=\""+ FormWebUrl +"\" type=\"text\" value=\""+ myWP.WebUrl +"\"><br>");
            output.Write("<span>Url Parameter (optional)</span><br><input name=\"" + FormWebUrlParameter + "\" type=\"text\" value=\"" + myWP.WebUrlParameter + "\"><br>");
            output.Write("<span>User</span><br><input name=\"" + FormWebUser + "\" type=\"text\" value=\"" + myWP.WebUser + "\"><br>");
            output.Write("<span>Password</span><br><input name=\"" + FormWebPassword + "\" type=\"password\" value=\"" + myWP.WebPassword + "\"><br>");
			output.Write("<span>"+WebErrorMessage+"</span><br>");

            output.Write("<span>Proxy (optional)</span><br><input name=\"" + FormProxyUrl + "\" type=\"text\" value=\"" + myWP.ProxyUrl + "\"><br>");
            output.Write("<span>User (optional)</span><br><input name=\"" + FormProxyUser + "\" type=\"text\" value=\"" + myWP.ProxyUser + "\"><br>");
            output.Write("<span>Password (optional)</span><br><input name=\"" + FormProxyPassword + "\" type=\"password\" value=\"" + myWP.ProxyPassword + "\"><br>");
            output.Write("<span>" + ProxyErrorMessage + "</span><br>");
		}


	}											
}
								
