using System;
using System.ComponentModel;
using System.IO;
using System.Net;
using System.Web.UI;
using Microsoft.SharePoint.WebPartPages;

namespace RH
{
    // <SafeControl Assembly="ShowWebsite, Version=1.0.0.0, Culture=neutral, PublicKeyToken=b17a955c3eada4c1" Namespace="RH" TypeName="*" Safe="True" />
    public class ShowWebsite : WebPart
    {
        #region Deklarationen
        private string _WebUrl = string.Empty;
        private string _WebUser = string.Empty;
        private string _WebPassword = string.Empty;
        private string _WebUrlParameter = string.Empty;
        private string _ProxyUrl = string.Empty;
        private string _ProxyUser = string.Empty;
        private string _ProxyPassword = string.Empty;
        #endregion

        #region Properties
        /// <summary>
        ///	This method gets the custom tool parts for this Web Part by overriding the
        ///	GetToolParts method of the WebPart base class. You must implement
        ///	custom tool parts in a separate class that derives from 
        ///	Microsoft.SharePoint.WebPartPages.ToolPart. 
        ///	</summary>
        public override ToolPart[] GetToolParts()
        {
            ToolPart[] toolparts = new ToolPart[3];
            WebPartToolPart wptp = new WebPartToolPart();
            CustomPropertyToolPart custom = new CustomPropertyToolPart();
            toolparts[0] = new PwdToolPart();
            toolparts[1] = custom;
            toolparts[2] = wptp;

            return toolparts;
        }

        #region Website
        [Browsable(false),
        Category("Website Authentification"),
        DefaultValue(""),
        WebPartStorage(Storage.Shared),
        FriendlyName("Website"),
        Description("Fill in the Url for the Website (http://server/default.aspx?{0}&{1}")]
        public string WebUrl
        {
            get { return _WebUrl; }
            set
            {
                if (value == null) _WebUrl = "";
                else
                {
                    string TempUrl = value;
                    if (TempUrl.IndexOf("http://") == -1 && TempUrl.IndexOf("https://") == -1)
                        TempUrl = "http://" + TempUrl;
                    _WebUrl = TempUrl;
                }
            }
        }

        [Browsable(false),
        Category("Website Authentification"),
        DefaultValue(""),
        WebPartStorage(Storage.Shared),
        FriendlyName("Url Parameter"),
        Description("Which Url Parameter should be retained to the displayes Website? (Parametername1,Parametername2")]
        public string WebUrlParameter
        {
            get { return _WebUrlParameter; }
            set
            {
                if (value == null) _WebUrlParameter = "";
                else _WebUrlParameter = value;
                //if(Usercontrol != null) Usercontrol.Password = password;
            }
        }


        [Browsable(false),
        Category("Website Authentification"),
        DefaultValue(""),
        WebPartStorage(Storage.Shared),
        FriendlyName("Password"),
        Description("Fill in the password for the Website")]
        public string WebPassword
        {
            get { return _WebPassword; }
            set
            {
                if (value == null) _WebPassword = "";
                else _WebPassword = value;
                //if(Usercontrol != null) Usercontrol.Password = password;
            }
        }

        [Browsable(false),
        Category("Website Authentificationg"),
        DefaultValue(""),
        WebPartStorage(Storage.Shared),
        FriendlyName("Username"),
        Description("Fill in the Username for the Website")]
        public string WebUser
        {
            get { return _WebUser; }
            set
            {
                if (value == null) _WebUser = "";
                else _WebUser = value;
                //if(Usercontrol != null) Usercontrol.User = _User;
            }
        }
        #endregion

        #region Proxy
        [Browsable(false),
       Category("Website Authentification"),
        DefaultValue(""),
        WebPartStorage(Storage.Shared),
        FriendlyName("Proxy"),
        Description("Fill in the address for the Proxy")]
        public string ProxyUrl
        {
            get { return _ProxyUrl; }
            set
            {
                if (value == null) _ProxyUrl = "";
                else
                {
                    //if (!string.IsNullOrEmpty(value))
                    //{
                    //    string TempUrl = value;
                    //    if (TempUrl.IndexOf("http://") == -1 && TempUrl.IndexOf("https://") == -1)
                    //        TempUrl = "http://" + TempUrl;
                    //    _ProxyUrl = TempUrl;
                    //    if (_ProxyUrl.LastIndexOf(":") < 6)
                    //        _ProxyUrl += ":80";
                    //}
                }
            }
        }

        [Browsable(false),
        Category("Website Authentification"),
        DefaultValue(""),
        WebPartStorage(Storage.Shared),
        FriendlyName("Password"),
        Description("Fill in the password for the Proxy")]
        public string ProxyPassword
        {
            get { return _ProxyPassword; }
            set
            {
                if (value == null) _ProxyPassword = "";
                else _ProxyPassword = value;
                //if(Usercontrol != null) Usercontrol.Password = password;
            }
        }

        [Browsable(false),
        Category("Website Authentificationg"),
        DefaultValue(""),
        WebPartStorage(Storage.Shared),
        FriendlyName("Username"),
        Description("Fill in the Username for the Proxy")]
        public string ProxyUser
        {
            get { return _ProxyUser; }
            set
            {
                if (value == null) _ProxyUser = "";
                else _ProxyUser = value;
                //if(Usercontrol != null) Usercontrol.User = _User;
            }
        }
        #endregion
        #endregion

        protected override void OnPreRender(EventArgs e)
        {
            Title = "ShowWebsite - Ren Hzser";
            base.OnPreRender(e);
        }

        protected override void RenderContents(HtmlTextWriter writer)
        {
            writer.Write(GetWebsite(_WebUrl, _WebUrlParameter));
        }

        private string GetWebsite(string Url, string WebUrlParameter)
        {
            string HTMLOutput;
            Uri WebUri = null;
            Uri ProxyUri = null;
            CredentialCache WebCreds = null;
            CredentialCache ProxyCreds = null;
            HttpWebResponse response = null;
            Stream stream = null;
            WebProxy proxy = null;

            try
            {
                if (string.IsNullOrEmpty(Url))
                    return "The Webite Url is empty.";

                #region Parameter
                //Ersetzt {x} durch den Namen und den Wert
                if (WebUrlParameter.Length != 0)
                {
                    string[] Parameter = WebUrlParameter.Split(';');
                    for (int i = 0; i < Parameter.Length; i++)
                    {
                        string QueryString = Page.Request.QueryString[Parameter[i]];
                        Url = Url.Replace("{" + i + "}", Parameter[i] + "=" + QueryString);
                    }
                }
                #endregion

                WebUri = new Uri(Url);
                WebRequest request = WebRequest.Create(WebUri);

                #region Authentification
                if (_WebUser.Length != 0 && _WebPassword.Length != 0)
                {
                    WebCreds = new CredentialCache();
                    WebCreds.Add(WebUri, "Basic", new NetworkCredential(_WebUser, _WebPassword));

                    // If required by the server, set the credentials.
                    request.Credentials = WebCreds;
                }
                #endregion

                #region Proxy
                // Set Proxy if configured
                if (_ProxyUrl.Length > 0)
                {
                    if (_ProxyUser.Length == 0 && _ProxyPassword.Length == 0)
                    {
                        ProxyCreds = new CredentialCache();
                        ProxyCreds.Add(ProxyUri, "Basic", new NetworkCredential(_ProxyUser, _ProxyPassword));
                        proxy.Credentials = ProxyCreds;
                    }

                    proxy.Address = ProxyUri;
                    request.Proxy = proxy;
                }
                #endregion

                // Get the response.
                response = (HttpWebResponse)request.GetResponse();
                stream = response.GetResponseStream();
                StreamReader sr = new StreamReader(stream);

                HTMLOutput = sr.ReadToEnd();
            }
            catch (Exception ex)
            {
                HTMLOutput = ex.Message;
            }
            finally
            {
                #region Dispose Objects
                if (WebCreds != null)
                    WebCreds.Remove(WebUri, "Basic");
                if (ProxyCreds != null)
                    ProxyCreds.Remove(ProxyUri, "Basic");
                if (response != null)
                    response.Close();
                if (stream != null)
                    stream.Dispose();
                #endregion
            }

            return HTMLOutput;
        }
    }
}
